@@ -1,5 +1,5 @@
+//  Sync'ed with help_mp-en.h 1.95
 //  Translated to Bulgarian Language file. Used encoding: M$ CP1251
-//  Sync'ed with help_mp-en.h 1.91.
 
 //   ,     ivan@cacad.com
 //         mplayer-dev-eng maillist
@@ -9,11 +9,6 @@
 // ========================= MPlayer help ===========================
 
 #ifdef HELP_MP_DEFINE_STATIC
-static char* banner_text=
-"\n\n"
-"MPlayer " VERSION "(C) 2000-2003 Arpad Gereoffy  \n"
-"(   ./DOCS/  manpage -> `man mplayer` )  \n";
-
 static char help_text[]=
 ":   mplayer [] [url | /]__\n"
 "\n"
@@ -103,21 +98,24 @@ static char help_text[]=
 "         ************************************************\n"\
 "         ****               ****\n"\
 "         ************************************************\n"\
-"!!!  ,   : \n"\
-"- -: \"\"  . :  -ao sdl \n"\
-"   ALSA 0.5  OSS   ALSA 0.9.  DOCS/sound.html\n"\
-"    !\n"\
-"      -autosync 30\n"\
-"-  .    -vo  (  : -vo help)\n"\
-"      -framedrop !   DOCS/video.html   .\n"\
-"-  .      dvd/divx     \n"\
-"    !   -hardframedrop\n"\
-"-  .      :\n"\
-"   -nobps  -ni  -mc 0  -forceidx\n"\
+" ,   : \n"\
+"- -: \"\"  . :\n"\
+"  -  -ao sdl   ALSA 0.5  OSS   ALSA 0.9. \n"\
+"  -       -autosync 30\n"\
+"-   .\n"\
+"  -    -vo  (  : -vo help)\n"\
+"        -framedrop !\n"\
+"-  .\n"\
+"  -      DVD/DivX     \n"\
+"      !   -hardframedrop\n"\
+"-  .\n"\
+"  -      :\n"\
+"    -nobps  -ni  -mc 0  -forceidx\n"\
 "-      (nfs/smb , cd, dvd, vcd  ..)\n"\
-"    -cache 8192\n"\
+"  -   -cache 8192\n"\
 "-   -cache     (non-interleaved)? \n"\
-"    -nocache\n"\
+"  -   -nocache\n"\
+" DOCS/video.html  DOCS/sound.html    \n"\
 "   ,  DOCS/bugreports.html !\n\n"
 
 #define MSGTR_NoGui "MPlayer       (GUI) !\n"
@@ -134,7 +132,7 @@ static char help_text[]=
 #define MSGTR_AvailableVideoCodecs "  :\n"
 #define MSGTR_AvailableAudioFm "\n   - /:\n"
 #define MSGTR_AvailableVideoFm "\n   - /:\n"
- #define MSGTR_AvailableFsType "Available fullscreen layer change modes:\n"
+#define MSGTR_AvailableFsType " e     :\n"
 #define MSGTR_UsingRTCTiming " Linux's hardware RTC  (%ldHz)\n"
 #define MSGTR_CannotReadVideoProperties ":        \n"
 #define MSGTR_NoStreamFound "   \n"
@@ -146,7 +144,7 @@ static char help_text[]=
 #define MSGTR_AOComment "AO: : %s\n"
 #define MSGTR_Video_NoVideo ":  ! ! !\n"
 #define MSGTR_NotInitializeVOPorVO "\n:       (-vop)    (-vo) !\n"
-#define MSGTR_Paused "\n------  -------\r"
+#define MSGTR_Paused "\n  =====    =====\r"
 #define MSGTR_PlaylistLoadUnable "\n     playlist %s\n"
 #define MSGTR_Exit_SIGILL_RTCpuSel \
 "- MPlayer crashed by an 'Illegal Instruction'.\n"\
@@ -169,7 +167,6 @@ static char help_text[]=
 
 // mencoder.c
 
-#define MSGTR_MEncoderCopyright "(C) 2000-2003 Arpad Gereoffy ( DOCS!)\n"
 #define MSGTR_UsingPass3ControllFile " pass3  : %s\n"
 #define MSGTR_MissingFilename "\n   !\n\n"
 #define MSGTR_CannotOpenFile_Device "    /\n"
@@ -549,7 +546,7 @@ static char help_text[]=
 #define MSGTR_PREFERENCES_LoadFullscreen "   "
 #define MSGTR_PREFERENCES_CacheSize "  : "
 #define MSGTR_PREFERENCES_XSCREENSAVER " XScreenSaver"
-//#define MSGTR_PREFERENCES_PlayBar " playbar"
+#define MSGTR_PREFERENCES_PlayBar "   "
 #define MSGTR_PREFERENCES_AutoSync "  (   ) "
 #define MSGTR_PREFERENCES_AutoSyncValue "  Autosync:"
 #define MSGTR_PREFERENCES_CDROMDevice "CD-ROM :"
