@@ -1,7 +1,7 @@
 /*
     Real parser & demuxer
     
-    (C) Alex Beregszaszi <alex@naxine.org>
+    (C) Alex Beregszaszi <alex@fsn.hu>
     
     Based on FFmpeg's libav/rm.c.
 
@@ -396,7 +396,7 @@ int demux_real_fill_buffer(demuxer_t *demuxer)
     version = stream_read_word(demuxer->stream); /* version */
     len = stream_read_word(demuxer->stream);
     if ((version==0x4441) && (len==0x5441)) { // new data chunk
-	mp_msg(MSGT_DEMUX,MSGL_INFO,"demux_real: New data chunk is comming!!!\n");
+	mp_msg(MSGT_DEMUX,MSGL_INFO,"demux_real: New data chunk is coming!!!\n");
 	stream_skip(demuxer->stream,14); 
 	demuxer->filepos = stream_tell(demuxer->stream);
         version = stream_read_word(demuxer->stream); /* version */
@@ -715,7 +715,7 @@ void demux_open_real(demuxer_t* demuxer)
 //    stream_skip(demuxer->stream, 4); /* number of headers */
 
     /* parse chunks */
-    for (i = 1; i < num_of_headers; i++)
+    for (i = 1; i <= num_of_headers; i++)
     {
 	int chunk_id, chunk_pos, chunk_size;
 	
